#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-aeson
version:              1.2.3
visibility:           public
id:                   lens-aeson-1.2.3-1cEIkdm98Ab2qkbTeqtrKc
key:                  lens-aeson-1.2.3-1cEIkdm98Ab2qkbTeqtrKc
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Data, JSON, Lenses
abi:                  110d78a867310cc7895704f10b31e11a
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lens-aeson-1.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lens-aeson-1.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lens-aeson-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-aeson
hs-libraries:         HSlens-aeson-1.2.3-1cEIkdm98Ab2qkbTeqtrKc
depends:
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT base-4.18.2.1
    bytestring-0.11.5.3 lens-5.3.4-CugvPwDQfTKJtJ2DRsVKfV
    scientific-0.3.8.1-5DbHtB8w5OO3mo7GyLG4Aa text-2.0.2
    text-short-0.1.6.1-K4y0z6pnN0NCPkIECGByqY
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits
    vector-0.13.2.0-1mI63yzxbUH28Wn11C5uSI

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

